@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010 Licq Developers <licq-dev@googlegroups.com>
+ * Copyright (C) 2010-2011 Licq Developers <licq-dev@googlegroups.com>
  *
  * Please refer to the COPYRIGHT file distributed with this source
  * distribution for the names of the individual contributors.
@@ -61,10 +61,6 @@ public:
   std::string getStatusMessage(unsigned status);
 
 private:
-  unsigned long getConvoId(const std::string& from);
-
-  unsigned long myNextConvoId;
-  std::map<std::string, unsigned long> myConvoIds;
 };
 
 } // namespace Jabber
