@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2007-2011 Licq developers
+ * Copyright (C) 2007-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 // Licq
 #include <licq/contactlist/user.h>
 #include <licq/icq/icq.h>
+#include <licq/plugin/pluginmanager.h>
 #include <licq/pluginsignal.h>
 #include <licq/socket.h>
 #include <licq/userevents.h>
@@ -498,12 +499,10 @@ bool ContactUserData::setData(const QVariant& value, int role)
     u->SetKeepAliasOnUpdate(true);
     u->setAlias(myAlias.toUtf8().data());
 
-    // Daemon doesn't send signal when alias is changed so trigger update from here
-    updateText(*u);
-    updateSorting();
+    Licq::gPluginManager.pushPluginSignal(new Licq::PluginSignal(
+        Licq::PluginSignal::SignalUser, Licq::PluginSignal::UserBasic, myUserId));
   }
 
-  emit dataChanged(this);
   return true;
 }
 
