@@ -1,7 +1,6 @@
-// -*- c-basic-offset: 2 -*-
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2007-2010 Licq developers
+ * Copyright (C) 2007-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,9 +30,8 @@
 #include <licq/contactlist/owner.h>
 #include <licq/contactlist/usermanager.h>
 #include <licq/daemon.h>
-#include <licq/icq.h>
-#include <licq/icqdefines.h>
-#include <licq/pluginmanager.h>
+#include <licq/icq/icq.h>
+#include <licq/plugin/pluginmanager.h>
 
 #include "config/contactlist.h"
 #include "config/general.h"
@@ -78,7 +76,7 @@ SystemMenu::SystemMenu(QWidget* parent)
   QAction* a;
 
   // Sub menu Debug
-  myDebugMenu = new QMenu(tr("Debug Level"));
+  myDebugMenu = new QMenu(tr("Debug Level"), this);
   connect(myDebugMenu, SIGNAL(triggered(QAction*)), SLOT(changeDebug(QAction*)));
   connect(myDebugMenu, SIGNAL(aboutToShow()), SLOT(aboutToShowDebugMenu()));
 #define ADD_DEBUG(text, data, checkable) \
@@ -97,7 +95,7 @@ SystemMenu::SystemMenu(QWidget* parent)
 #undef ADD_DEBUG
 
   // Sub menu System Functions
-  myOwnerAdmMenu = new QMenu(tr("S&ystem Functions"));
+  myOwnerAdmMenu = new QMenu(tr("S&ystem Functions"), this);
   myOwnerAdmMenu->addAction(tr("&View System Messages..."), gLicqGui, SLOT(showAllOwnerEvents()));
   myOwnerAdmMenu->addSeparator();
   myOwnerAdmSeparator = myOwnerAdmMenu->addSeparator();
@@ -106,7 +104,7 @@ SystemMenu::SystemMenu(QWidget* parent)
   myOwnerAdmMenu->addMenu(myDebugMenu);
 
   // Sub menu User Functions
-  myUserAdmMenu = new QMenu(tr("User &Functions"));
+  myUserAdmMenu = new QMenu(tr("User &Functions"), this);
   myUserAdmMenu->addAction(tr("&Add User..."), this, SLOT(showAddUserDlg()));
   myAddGroupAction = myUserAdmMenu->addAction(tr("A&dd Group..."), this, SLOT(showAddGroupDlg()));
   myUserSearchAction = myUserAdmMenu->addAction(tr("S&earch for User..."), this, SLOT(showSearchUserDlg()));
@@ -123,7 +121,7 @@ SystemMenu::SystemMenu(QWidget* parent)
   myUserAdmMenu->addAction(tr("&Save All Users"), this, SLOT(saveAllUsers()));
 
   // Sub menu Follow Me
-  myFollowMeMenu = new QMenu(tr("ICQ Phone \"Follow Me\""));
+  myFollowMeMenu = new QMenu(tr("ICQ Phone \"Follow Me\""), this);
   myFollowMeActions = new QActionGroup(this);
   connect(myFollowMeActions, SIGNAL(triggered(QAction*)), SLOT(setFollowMeStatus(QAction*)));
 #define ADD_PFM(text, data) \
@@ -131,13 +129,13 @@ SystemMenu::SystemMenu(QWidget* parent)
     a->setCheckable(true); \
     a->setData(static_cast<unsigned int>(data)); \
     myFollowMeMenu->addAction(a);
-  ADD_PFM(tr("Don't Show"), ICQ_PLUGIN_STATUSxINACTIVE);
-  ADD_PFM(tr("Available"), ICQ_PLUGIN_STATUSxACTIVE);
-  ADD_PFM(tr("Busy"), ICQ_PLUGIN_STATUSxBUSY);
+  ADD_PFM(tr("Don't Show"), CICQDaemon::IcqPluginInactive);
+  ADD_PFM(tr("Available"), CICQDaemon::IcqPluginActive);
+  ADD_PFM(tr("Busy"), CICQDaemon::IcqPluginBusy);
 #undef ADD_PFM
 
   // Sub menu Status
-  myStatusMenu = new QMenu(tr("&Status"));
+  myStatusMenu = new QMenu(tr("&Status"), this);
   myStatusActions = new QActionGroup(this);
   connect(myStatusActions, SIGNAL(triggered(QAction*)), SLOT(setMainStatus(QAction*)));
   myStatusSeparator = myStatusMenu->addSeparator();
@@ -162,7 +160,7 @@ SystemMenu::SystemMenu(QWidget* parent)
   myStatusInvisibleAction->setCheckable(true);
 
   // Sub menu Group
-  myGroupMenu = new QMenu(tr("&Group"));
+  myGroupMenu = new QMenu(tr("&Group"), this);
   myUserGroupActions = new QActionGroup(this);
   connect(myGroupMenu, SIGNAL(aboutToShow()), SLOT(aboutToShowGroupMenu()));
   connect(myUserGroupActions, SIGNAL(triggered(QAction*)), SLOT(setCurrentGroup(QAction*)));
@@ -182,7 +180,7 @@ SystemMenu::SystemMenu(QWidget* parent)
 #undef ADD_SYSTEMGROUP
 
   // Sub menu Help
-  myHelpMenu = new QMenu(tr("&Help"));
+  myHelpMenu = new QMenu(tr("&Help"), this);
   myHelpMenu->addAction(tr("&Hints..."), gMainWindow, SLOT(showHints()));
   myHelpMenu->addAction(tr("&About..."), gMainWindow, SLOT(showAboutBox()));
   myHelpMenu->addAction(tr("&Statistics..."), gMainWindow, SLOT(showStats()));
@@ -343,8 +341,8 @@ void SystemMenu::addOwner(const Licq::UserId& userId)
   if (protocol.get() == NULL)
     return;
 
-  OwnerData* newOwner = new OwnerData(ppid, protocol->getName(),
-      protocol->getSendFunctions(), this);
+  OwnerData* newOwner = new OwnerData(ppid, protocol->name().c_str(),
+      protocol->capabilities(), this);
   QMenu* ownerAdmin = newOwner->getOwnerAdmMenu();
   QMenu* ownerStatus = newOwner->getStatusMenu();
   myOwnerAdmMenu->insertMenu(myOwnerAdmSeparator, ownerAdmin);
@@ -427,7 +425,7 @@ void SystemMenu::aboutToShowFollowMeMenu()
   if (!o.isLocked())
     return;
 
-  int status = o->PhoneFollowMeStatus();
+  int status = o->phoneFollowMeStatus();
 
   foreach (QAction* a, myFollowMeActions->actions())
     if (a->data().toInt() == status)
