@@ -1,7 +1,6 @@
-// -*- c-basic-offset: 2 -*-
 /* ----------------------------------------------------------------------------
  * Licq - A ICQ Client for Unix
- * Copyright (C) 1998-2010 Licq developers
+ * Copyright (C) 1998-2011 Licq developers
  *
  * This program is licensed under the terms found in the LICENSE file.
  */
@@ -40,10 +39,11 @@
 #include <licq/contactlist/user.h>
 #include <licq/contactlist/usermanager.h>
 #include <licq/daemon.h>
-#include <licq/icq.h>
+#include <licq/icq/icq.h>
 #include <licq/logging/log.h>
+#include <licq/logging/logservice.h>
 #include <licq/logging/logutils.h>
-#include <licq/pluginmanager.h>
+#include <licq/plugin/pluginmanager.h>
 #include <licq/pluginsignal.h>
 #include <licq/protocolmanager.h>
 #include <licq/translator.h>
@@ -51,12 +51,12 @@
 
 #include "gettext.h"
 #include "licq.h"
-#include "support.h"
 
 using std::string;
 using Licq::UserId;
 using Licq::gDaemon;
 using Licq::gLog;
+using Licq::gLogService;
 using Licq::gPluginManager;
 using Licq::gProtocolManager;
 using Licq::gUserManager;
@@ -145,6 +145,8 @@ static const char* const HELP_HELP = tr(
         "\t\tPrint help information for <command> or for all commands.\n");
 #define MAX_ARGV 64
 
+const unsigned short MAX_UIN_DIGITS  = 13;
+
 enum 
 {
   CL_UNKNOWN=-1,
@@ -154,9 +156,8 @@ enum
 struct command_t
 {
   const char *const szName;
-  int (*fnc)(int, const char *const*, void *);
+  int (*fnc)(int, const char* const*);
   const char *const szHelp;
-  int bHelp;
 };
 
 static int process_tok(const command_t *table,const char *tok);
@@ -210,9 +211,9 @@ static bool buffer_get_ids(char* buffer, char** szId, unsigned long* nPPID,
 
     BOOST_FOREACH(Licq::ProtocolPlugin::Ptr plugin, plugins)
     {
-      if ( !strcmp(plugin->getName(), buffer) )
+      if (plugin->name() == buffer)
       {
-        *nPPID = plugin->getProtocolId();
+        *nPPID = plugin->protocolId();
         found = true;
       }
     }
@@ -307,7 +308,7 @@ static bool atoid(const char* buff, bool bOnList, char** szId, unsigned long* nP
 }
 
 // status 
-static int fifo_status( int argc, const char *const *argv, void* /* data */)
+static int fifo_status(int argc, const char* const* argv)
 {
   const char *szStatus = argv[1];
 
@@ -333,6 +334,7 @@ static int fifo_status( int argc, const char *const *argv, void* /* data */)
   {
     Licq::OwnerWriteGuard o(LICQ_PPID);
     o->setAutoResponse(argv[2]);
+    o->save(Licq::Owner::SaveOwnerInfo);
   }
 
   return 0;
@@ -340,7 +342,7 @@ static int fifo_status( int argc, const char *const *argv, void* /* data */)
 
 
 // auto_response <auto response>
-static int fifo_auto_response( int argc, const char *const *argv, void* /* data */)
+static int fifo_auto_response(int argc, const char* const* argv)
 {
   if( argc == 1 )
   {
@@ -350,12 +352,13 @@ static int fifo_auto_response( int argc, const char *const *argv, void* /* data
 
   Licq::OwnerWriteGuard o(LICQ_PPID);
   o->setAutoResponse(argv[1]);
+  o->save(Licq::Owner::SaveOwnerInfo);
 
   return 0;
 }
 
 // message <buddy> <message>
-static int fifo_message ( int argc, const char *const *argv, void* /* data */)
+static int fifo_message(int argc, const char* const* argv)
 {
   unsigned long nPPID;
   char *szId = 0;
@@ -367,7 +370,7 @@ static int fifo_message ( int argc, const char *const *argv, void* /* data */)
   }
 
   if (atoid(argv[1], false, &szId, &nPPID))
-    gProtocolManager.sendMessage(UserId(szId, nPPID), argv[2], true, 0);
+    gProtocolManager.sendMessage(UserId(szId, nPPID), argv[2]);
 
   else
     ReportBadBuddy(argv[0], argv[1]);
@@ -378,7 +381,7 @@ static int fifo_message ( int argc, const char *const *argv, void* /* data */)
 }
 
 // url <buddy> <url> [<description>]
-static int fifo_url ( int argc, const char *const *argv, void* /* data */)
+static int fifo_url(int argc, const char* const* argv)
 {
   const char *szDescr;
   unsigned long nPPID;
@@ -393,7 +396,7 @@ static int fifo_url ( int argc, const char *const *argv, void* /* data */)
   if (atoid(argv[1], false, &szId, &nPPID))
   {
     szDescr = (argc > 3) ? argv[3] : "" ;
-    gProtocolManager.sendUrl(UserId(szId, nPPID), argv[2], szDescr, true, false);
+    gProtocolManager.sendUrl(UserId(szId, nPPID), argv[2], szDescr);
   }
   else
     ReportBadBuddy(argv[0],argv[1]);
@@ -404,9 +407,8 @@ static int fifo_url ( int argc, const char *const *argv, void* /* data */)
 }
 
 //sms <buddy> <message>
-static int fifo_sms(int argc, const char *const *argv, void *data)
+static int fifo_sms(int argc, const char *const *argv)
 {
-  CICQDaemon *d = (CICQDaemon *) data;
   unsigned long nPPID;
   char *szId = 0;
 
@@ -430,7 +432,7 @@ static int fifo_sms(int argc, const char *const *argv, void *data)
         }
       }
       if (!number.empty())
-        d->icqSendSms(userId, number, argv[2]);
+        gLicqDaemon->icqSendSms(userId, number, argv[2]);
       else
         gLog.error("Unable to send SMS to %s, no SMS number found", szId);
     }
@@ -446,22 +448,20 @@ static int fifo_sms(int argc, const char *const *argv, void *data)
 }
 
 // sms-number <number> <message>
-static int fifo_sms_number(int argc, const char *const *argv, void *data)
+static int fifo_sms_number(int argc, const char *const *argv)
 {
-  CICQDaemon *d = (CICQDaemon *) data;
-
   if (argc < 3)
   {
     ReportMissingParams(argv[0]);
     return -1;
   }
 
-  d->icqSendSms(gUserManager.ownerUserId(LICQ_PPID), argv[1], argv[2]);
+  gLicqDaemon->icqSendSms(gUserManager.ownerUserId(LICQ_PPID), argv[1], argv[2]);
   return 0;
 }
 
 // redirect <file>
-static int fifo_redirect ( int argc, const char *const *argv, void* /* data */)
+static int fifo_redirect(int argc, const char* const* argv)
 {
   if( argc == 1 )
   {
@@ -469,7 +469,8 @@ static int fifo_redirect ( int argc, const char *const *argv, void* /* data */)
     return -1;
   }
 
-  if ( !Redirect(argv[1]) )
+  int fd = open(argv[1], O_WRONLY | O_CREAT | O_APPEND, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP);
+  if (fd == -1 || dup2(fd, STDERR_FILENO) == -1)
   {
     gLog.warning(tr("%s: redirection to \"%s\" failed: %s"),
         argv[0], argv[1],strerror(errno));
@@ -482,7 +483,7 @@ static int fifo_redirect ( int argc, const char *const *argv, void* /* data */)
 }
 
 // debuglvl <level>
-static int fifo_debuglvl ( int argc, const char *const *argv, void* /* data */)
+static int fifo_debuglvl(int argc, const char* const* argv)
 {
   int nRet = 0; 
  
@@ -491,14 +492,14 @@ static int fifo_debuglvl ( int argc, const char *const *argv, void* /* data */)
   else
   {
     unsigned int mask = Licq::LogUtils::convertOldBitmaskToNew(::atoi(argv[1]));
-    LogService::instance().getDefaultLogSink()->setLogLevelsFromBitmask(mask);
+    gLogService.getDefaultLogSink()->setLogLevelsFromBitmask(mask);
   }
 
   return -nRet;
 }
 
 // adduser <buddy>
-static int fifo_adduser(int argc, const char* const* argv, void* /* data */)
+static int fifo_adduser(int argc, const char* const* argv)
 {
   unsigned long nPPID;
   char *szId = 0;
@@ -522,7 +523,7 @@ static int fifo_adduser(int argc, const char* const* argv, void* /* data */)
 }
 
 // userinfo <buddy>
-static int fifo_userinfo ( int argc, const char *const *argv, void* /* data */)
+static int fifo_userinfo(int argc, const char* const* argv)
 {
   unsigned long nPPID;
   char *szId = 0; 
@@ -552,7 +553,7 @@ static int fifo_userinfo ( int argc, const char *const *argv, void* /* data */)
   return ret;
 }
 
-static int fifo_setpicture(int argc, const char* const* argv, void* /* data */)
+static int fifo_setpicture(int argc, const char* const* argv)
 {
   if (argc < 2)
   {
@@ -571,9 +572,9 @@ static int fifo_setpicture(int argc, const char* const* argv, void* /* data */)
 
     BOOST_FOREACH(Licq::ProtocolPlugin::Ptr plugin, plugins)
     {
-      if (strcmp(plugin->getName(), argv[2]) == 0)
+      if (plugin->name() == argv[2])
       {
-        protocolId = plugin->getProtocolId();
+        protocolId = plugin->protocolId();
         break;
       }
     }
@@ -595,7 +596,7 @@ static int fifo_setpicture(int argc, const char* const* argv, void* /* data */)
         o->SetPicture(NULL);
       else
         o->SetPicture(argv[1]);
-      o->SavePictureInfo();
+      o->save(Licq::Owner::SavePictureInfo);
       Licq::gUserManager.notifyUserUpdated(o->id(), Licq::PluginSignal::UserPicture);
     }
   }
@@ -611,7 +612,7 @@ static int fifo_setpicture(int argc, const char* const* argv, void* /* data */)
         o->SetPicture(NULL);
       else
         o->SetPicture(argv[1]);
-      o->SavePictureInfo();
+      o->save(Licq::Owner::SavePictureInfo);
       Licq::gUserManager.notifyUserUpdated(o->id(), Licq::PluginSignal::UserPicture);
     }
   }
@@ -621,14 +622,14 @@ static int fifo_setpicture(int argc, const char* const* argv, void* /* data */)
 }
 
 // exit
-static int fifo_exit(int /* argc */, const char* const* /* argv */, void* /* data */)
+static int fifo_exit(int /* argc */, const char* const* /* argv */)
 {
   gDaemon.Shutdown();
   return 0;
 }
 
 // ui_viewevent [<buddy>]
-static int fifo_ui_viewevent ( int argc, const char *const *argv, void* /* data */)
+static int fifo_ui_viewevent(int argc, const char* const* argv)
 {
   unsigned long nPPID;
   char *szId = 0; 
@@ -655,7 +656,7 @@ static int fifo_ui_viewevent ( int argc, const char *const *argv, void* /* data
 }
 
 // ui_message <buddy>
-static int fifo_ui_message ( int argc, const char *const *argv, void* /* data */)
+static int fifo_ui_message(int argc, const char* const* argv)
 {
   unsigned long nPPID = 0;
   char *szId = 0;
@@ -678,19 +679,19 @@ static int fifo_ui_message ( int argc, const char *const *argv, void* /* data */
   return nRet;
 }
 
-static int fifo_plugin_list(int /* argc */, const char* const* /* argv */, void* /* data */)
+static int fifo_plugin_list(int /* argc */, const char* const* /* argv */)
 {
   Licq::GeneralPluginsList plugins;
   gPluginManager.getGeneralPluginsList(plugins);
 
   BOOST_FOREACH(Licq::GeneralPlugin::Ptr plugin, plugins)
   {
-    gLog.info("[%3d] %s\n", plugin->getId(), plugin->getName());
+    gLog.info("[%3d] %s\n", plugin->id(), plugin->name().c_str());
   }
   return 0;
 }
 
-static int fifo_plugin_load(int argc, const char* const* argv, void* /* data */)
+static int fifo_plugin_load(int argc, const char* const* argv)
 {
   if (argc == 1)
   {
@@ -705,7 +706,7 @@ static int fifo_plugin_load(int argc, const char* const* argv, void* /* data */)
   return -1;
 }
 
-static int fifo_plugin_unload(int argc, const char* const* argv, void* /* data */)
+static int fifo_plugin_unload(int argc, const char* const* argv)
 {
   if( argc == 1 )
   {
@@ -718,7 +719,7 @@ static int fifo_plugin_unload(int argc, const char* const* argv, void* /* data *
 
   BOOST_FOREACH(Licq::GeneralPlugin::Ptr plugin, plugins)
   {
-    if (strcmp(plugin->getName(), argv[1]) == 0)
+    if (plugin->name() == argv[1])
     {
       plugin->shutdown();
       return 0;
@@ -728,19 +729,19 @@ static int fifo_plugin_unload(int argc, const char* const* argv, void* /* data *
   return -1;
 }
 
-static int fifo_proto_plugin_list(int /* argc */, const char* const* /* argv */, void* /* data */)
+static int fifo_proto_plugin_list(int /* argc */, const char* const* /* argv */)
 {
   Licq::ProtocolPluginsList plugins;
   gPluginManager.getProtocolPluginsList(plugins);
 
   BOOST_FOREACH(Licq::ProtocolPlugin::Ptr plugin, plugins)
   {
-    gLog.info("[%3d] %s\n", plugin->getId(), plugin->getName());
+    gLog.info("[%3d] %s\n", plugin->id(), plugin->name().c_str());
   }
   return 0;
 }
 
-static int fifo_proto_plugin_load(int argc, const char* const* argv, void* /* data */)
+static int fifo_proto_plugin_load(int argc, const char* const* argv)
 {
   if (argc == 1)
   {
@@ -755,7 +756,7 @@ static int fifo_proto_plugin_load(int argc, const char* const* argv, void* /* da
   return -1;
 }
 
-static int fifo_proto_plugin_unload(int argc, const char* const* argv, void* /* data */)
+static int fifo_proto_plugin_unload(int argc, const char* const* argv)
 {
   if (argc == 1)
   {
@@ -768,7 +769,7 @@ static int fifo_proto_plugin_unload(int argc, const char* const* argv, void* /*
 
   BOOST_FOREACH(Licq::ProtocolPlugin::Ptr plugin, plugins)
   {
-    if (strcmp(plugin->getName(), argv[1]) == 0)
+    if (plugin->name() == argv[1])
     {
       plugin->shutdown();
       return 0;
@@ -778,16 +779,43 @@ static int fifo_proto_plugin_unload(int argc, const char* const* argv, void* /*
   return -1;
 }
 
-static int fifo_help ( int argc, const char *const *argv, void *data)
+static int fifo_help(int argc, const char *const *argv);
+
+static struct command_t fifocmd_table[]=
+{
+  {"status",              fifo_status,              HELP_STATUS},
+  {"auto_response",       fifo_auto_response,       HELP_AUTO},
+  {"message",             fifo_message,             HELP_MSG},
+  {"url",                 fifo_url,                 HELP_URL},
+  {"sms",                 fifo_sms,                 HELP_SMS},
+  {"sms-number",          fifo_sms_number,          HELP_SMS_NUMBER},
+  {"redirect",            fifo_redirect,            HELP_REDIRECT},
+  {"debuglvl",            fifo_debuglvl,            HELP_DEBUGLVL},
+  {"adduser",             fifo_adduser,             HELP_ADDUSER},
+  {"userinfo",            fifo_userinfo,            HELP_USERINFO},
+  {"setpicture",          fifo_setpicture,          HELP_SETPICTURE},
+  {"exit",                fifo_exit,                HELP_EXIT},
+  {"ui_viewevent",        fifo_ui_viewevent,        HELP_UIVIEWEVENT},
+  {"ui_message",          fifo_ui_message,          HELP_UIMESSAGE},
+  {"list_plugins",        fifo_plugin_list,         HELP_PLUGINLIST},
+  {"load_plugin",         fifo_plugin_load,         HELP_PLUGINLOAD},
+  {"unload_plugin",       fifo_plugin_unload,       HELP_PLUGINUNLOAD},
+  {"list_proto_plugins",  fifo_proto_plugin_list,   HELP_PROTOPLUGINLIST},
+  {"load_proto_plugin",   fifo_proto_plugin_load,   HELP_PROTOPLUGINLOAD},
+  {"unload_proto_plugin", fifo_proto_plugin_unload, HELP_PROTOPLUGINUNLOAD},
+  {"help",                fifo_help,                HELP_HELP},
+  {NULL,                  NULL,                     NULL}
+};
+
+static int fifo_help(int argc, const char* const* argv)
 {
-  struct command_t *table = (struct command_t *)data;
   int i,j;
 
   if( argc == 1 )
   {
     gLog.info(tr("%sFifo commands:\n"), L_FIFOxSTR);
-    for( i=0; table[i].fnc ; i++ )
-      gLog.info("%s%s\n",L_BLANKxSTR,table[i].szName);
+    for (i = 0; fifocmd_table[i].fnc; i++)
+      gLog.info("                %s", fifocmd_table[i].szName);
     gLog.info(tr("%s: Type `help command'\n"), L_FIFOxSTR);
   }
   else 
@@ -798,20 +826,20 @@ static int fifo_help ( int argc, const char *const *argv, void *data)
       {
         // show help for all commands 
         j = 0;
-        while (table[j].szName)
+        while (fifocmd_table[j].szName)
         {
           gLog.info(tr("%s %s: help for `%s'\n%s\n"),
-                    L_FIFOxSTR, argv[0], table[j].szName, table[j].szHelp);
+              L_FIFOxSTR, argv[0], fifocmd_table[j].szName, fifocmd_table[j].szHelp);
           j++;
 	}
       }
       else
       {
         // show help for a specific command
-        j = process_tok(table, argv[i]);
+        j = process_tok(fifocmd_table, argv[i]);
         if (j >= 0)
           gLog.info(tr("%s %s: help for `%s'\n%s\n"),
-                    L_FIFOxSTR, argv[0], argv[i], table[j].szHelp);
+              L_FIFOxSTR, argv[0], argv[i], fifocmd_table[j].szHelp);
         else
           gLog.info(tr("%s %s: unknown command `%s'\n"),
                     L_FIFOxSTR, argv[0], argv[i]);
@@ -822,32 +850,6 @@ static int fifo_help ( int argc, const char *const *argv, void *data)
 }
 
 
-static struct command_t fifocmd_table[]=
-{
-  {"status",              fifo_status,              HELP_STATUS,            0},
-  {"auto_response",       fifo_auto_response,       HELP_AUTO,              0},
-  {"message",             fifo_message,             HELP_MSG,               0},
-  {"url",                 fifo_url,                 HELP_URL,               0},
-  {"sms",                 fifo_sms,                 HELP_SMS,               0},
-  {"sms-number",          fifo_sms_number,          HELP_SMS_NUMBER,        0},
-  {"redirect",            fifo_redirect,            HELP_REDIRECT,          0},
-  {"debuglvl",            fifo_debuglvl,            HELP_DEBUGLVL,          0},
-  {"adduser",             fifo_adduser,             HELP_ADDUSER,           0},
-  {"userinfo",            fifo_userinfo,            HELP_USERINFO,          0},
-  {"setpicture",          fifo_setpicture,          HELP_SETPICTURE,        0},
-  {"exit",                fifo_exit,                HELP_EXIT,              0},
-  {"ui_viewevent",        fifo_ui_viewevent,        HELP_UIVIEWEVENT,       0},
-  {"ui_message",          fifo_ui_message,          HELP_UIMESSAGE,         0},
-  {"list_plugins",        fifo_plugin_list,         HELP_PLUGINLIST,        0},
-  {"load_plugin",         fifo_plugin_load,         HELP_PLUGINLOAD,        0},
-  {"unload_plugin",       fifo_plugin_unload,       HELP_PLUGINUNLOAD,      0},
-  {"list_proto_plugins",  fifo_proto_plugin_list,   HELP_PROTOPLUGINLIST,   0},
-  {"load_proto_plugin",   fifo_proto_plugin_load,   HELP_PROTOPLUGINLOAD,   0},
-  {"unload_proto_plugin", fifo_proto_plugin_unload, HELP_PROTOPLUGINUNLOAD, 0},
-  {"help",                fifo_help,                HELP_HELP,              1},
-  {NULL,                  NULL,                     NULL,                   0}
-};
-
 //-----ProcessFifo--------------------------------------------------------------
 static char getQuotedChar( char c )
 {
@@ -871,7 +873,7 @@ static char getQuotedChar( char c )
  * given a command line string p, fills argv and argc. 
  * p is modified.
  */
-static bool line2argv( char *p, char **argv, int *argc, int size )
+static bool line2argv( char *p, const char **argv, int *argc, int size )
 {
   char *q;
   bool bQuote;
@@ -993,7 +995,7 @@ void Fifo::process(const string& buf)
 {
 #ifdef USE_FIFO
   int argc, index;
-  char * argv[MAX_ARGV];
+  const char* argv[MAX_ARGV];
   char *szBuf = strdup(buf.c_str());
 
   if( szBuf == NULL )
@@ -1012,14 +1014,9 @@ void Fifo::process(const string& buf)
     case CL_NONE:
       break;
     default:
-      argv[0] = (char *)fifocmd_table[index].szName;
+      argv[0] = fifocmd_table[index].szName;
       if( fifocmd_table[index].fnc )
-      {
-        if(fifocmd_table[index].bHelp)
-          fifocmd_table[index].fnc(argc,argv,(void *)fifocmd_table);
-        else
-          fifocmd_table[index].fnc(argc,argv,this);
-      }
+        fifocmd_table[index].fnc(argc, argv);
       break;
   }
   
