@@ -1,4 +1,3 @@
-// -*- c-basic-offset: 2 -*-
 /* ----------------------------------------------------------------------------
  * Licq - A ICQ Client for Unix
  * Copyright (C) 1998-2011 Licq developers
@@ -8,7 +7,7 @@
 
 #include "config.h"
 
-#include <licq/icqchat.h>
+#include <licq/icq/chat.h>
 
 #include <cctype>
 #include <cstdio>
@@ -21,12 +20,9 @@
 #include <licq/daemon.h>
 #include <licq/translator.h>
 
-#include "icq/icq.h"
-#include "icq/packet.h"
-#include "support.h"
-
-// Localization
-#include "gettext.h"
+#include "icq.h"
+#include "packet.h"
+#include "../gettext.h"
 
 using namespace std;
 using Licq::gDaemon;
@@ -126,7 +122,7 @@ CChatClient::CChatClient(const Licq::User* u)
   myUserId = u->id();
   m_nIp = u->Ip();
   m_nIntIp = u->IntIp();
-  m_nMode = u->Mode();
+  m_nMode = (u->directMode() ? MODE_DIRECT : MODE_INDIRECT);
   m_nSession = 0;
   m_nHandshake = 0x65;
 
@@ -327,7 +323,7 @@ CPChat_ColorFont::CPChat_ColorFont(const string& localName, unsigned short nLoca
   buffer->PackUnsignedLong(m_nPort);
   buffer->PackUnsignedLong(s_nLocalIp);
   buffer->PackUnsignedLong(s_nRealIp);
-  buffer->PackChar(s_nMode);
+  buffer->PackChar(gIcqProtocol.directMode() ? MODE_DIRECT : MODE_INDIRECT);
   buffer->PackUnsignedShort(m_nSession);
   buffer->PackUnsignedLong(m_nFontSize);
   buffer->PackUnsignedLong(m_nFontFace);
@@ -420,7 +416,7 @@ CPChat_Font::CPChat_Font(unsigned short nLocalPort, unsigned short nSession,
   buffer->PackUnsignedLong(m_nPort);
   buffer->PackUnsignedLong(s_nLocalIp);
   buffer->PackUnsignedLong(s_nRealIp);
-  buffer->PackChar(s_nMode);
+  buffer->PackChar(gIcqProtocol.directMode() ? MODE_DIRECT : MODE_INDIRECT);
   buffer->PackUnsignedShort(nSession);//0x5A89);
   buffer->PackUnsignedLong(m_nFontSize);
   buffer->PackUnsignedLong(m_nFontFace);
@@ -680,7 +676,7 @@ bool CChatManager::StartChatServer()
 {
   if (gDaemon.StartTCPServer(&chatServer) == -1)
   {
-    gLog.warning(tr("%sNo more ports available, add more or close open chat/file sessions.\n"), L_WARNxSTR);
+    gLog.warning(tr("No more ports available, add more or close open chat/file sessions."));
     return false;
   }
 
@@ -753,14 +749,14 @@ bool CChatManager::ConnectToChat(CChatClient *c)
     if (temp_user.isLocked())
     {
       bSendIntIp = temp_user->SendIntIp();
-      bTryDirect = temp_user->Version() <= 6 || temp_user->Mode() == MODE_DIRECT;
+      bTryDirect = temp_user->Version() <= 6 || temp_user->directMode();
     }
   }
 
   bool bSuccess = false;
   if (bTryDirect)
   {
-    gLog.info("%sChat: Connecting to server.\n", L_TCPxSTR);
+    gLog.info(tr("Chat: Connecting to server."));
     bSuccess = gIcqProtocol.OpenConnectionToUser("chat", c->m_nIp, c->m_nIntIp,
                                             &u->sock, c->m_nPort, bSendIntIp);
   }
@@ -808,8 +804,8 @@ bool CChatManager::ConnectToChat(CChatClient *c)
 bool CChatManager::SendChatHandshake(CChatUser *u)
 {
   CChatClient *c = u->m_pClient;
-  
-  gLog.info(tr("%sChat: Shaking hands [v%d].\n"), L_TCPxSTR, VersionToUse(c->m_nVersion));
+
+  gLog.info(tr("Chat: Shaking hands [v%d]."), VersionToUse(c->m_nVersion));
 
   // Send handshake packet:
   if (!IcqProtocol::handshake_Send(&u->sock, c->myUserId, LocalPort(),
@@ -822,7 +818,7 @@ bool CChatManager::SendChatHandshake(CChatUser *u)
      m_nColorBack[0], m_nColorBack[1], m_nColorBack[2]);
   u->sock.SendPacket(p_color.getBuffer());
 
-  gLog.info(tr("%sChat: Waiting for color/font response.\n"), L_TCPxSTR);
+  gLog.info(tr("Chat: Waiting for color/font response."));
 
   u->state = CHAT_STATE_WAITxFORxCOLORxFONT;
 
@@ -860,7 +856,7 @@ void CChatManager::AcceptReverseConnection(Licq::TCPSocket* s)
   sockman.DropSocket(&u->sock);
   myThreadPipe.putChar('R');
 
-  gLog.info(tr("%sChat: Received reverse connection.\n"), L_TCPxSTR);
+  gLog.info(tr("Chat: Received reverse connection."));
 }
 
 
@@ -885,10 +881,9 @@ bool CChatManager::ProcessPacket(CChatUser *u)
   if (!u->sock.RecvPacket())
   {
     if (u->sock.Error() == 0)
-      gLog.info(tr("%sChat: Remote end disconnected.\n"), L_TCPxSTR);
+      gLog.info(tr("Chat: Remote end disconnected."));
     else
-      gLog.info(tr("%sChat: Lost remote end:\n%s%s\n"), L_TCPxSTR,
-          L_BLANKxSTR, u->sock.errorStr().c_str());
+      gLog.info(tr("Chat: Lost remote end: %s"), u->sock.errorStr().c_str());
     return false;
   }
 
@@ -902,7 +897,7 @@ bool CChatManager::ProcessPacket(CChatUser *u)
       // get the handshake packet
       if (!IcqProtocol::Handshake_Recv(&u->sock, LocalPort(), false, true))
       {
-        gLog.warning("%sChat: Bad handshake.\n", L_ERRORxSTR);
+        gLog.warning(tr("Chat: Bad handshake."));
         return false;
       }
       switch (u->sock.Version())
@@ -924,7 +919,7 @@ bool CChatManager::ProcessPacket(CChatUser *u)
           u->m_pClient->LoadFromHandshake_v7(handshake);
           break;
       }
-      gLog.info(tr("%sChat: Received handshake from %s [v%ld].\n"), L_TCPxSTR,
+      gLog.info(tr("Chat: Received handshake from %s [v%ld]."),
           u->m_pClient->myUserId.toString().c_str(), u->sock.Version());
       u->myUserId = u->m_pClient->myUserId;
 
@@ -957,7 +952,7 @@ bool CChatManager::ProcessPacket(CChatUser *u)
         m_nColorBack[0], m_nColorBack[1], m_nColorBack[2]);
         u->sock.SendPacket(p_color.getBuffer());
 
-        gLog.info("%sChat: Waiting for color/font response.\n", L_TCPxSTR);
+        gLog.info(tr("Chat: Waiting for color/font response."));
 
         u->state = CHAT_STATE_WAITxFORxCOLORxFONT;
       }
@@ -970,7 +965,7 @@ bool CChatManager::ProcessPacket(CChatUser *u)
 
     case CHAT_STATE_WAITxFORxCOLOR:  // we just received the color packet
     {
-      gLog.info(tr("%sChat: Received color packet.\n"), L_TCPxSTR);
+      gLog.info(tr("Chat: Received color packet."));
 
       CPChat_Color pin(u->sock.RecvBuffer());
 
@@ -1006,8 +1001,7 @@ bool CChatManager::ProcessPacket(CChatUser *u)
           myFontFamily, m_nFontEncoding, m_nFontStyle, l);
       if (!u->sock.SendPacket(p_colorfont.getBuffer()))
       {
-        gLog.error("%sChat: Send error (color/font packet):\n%s%s\n",
-            L_ERRORxSTR, L_BLANKxSTR, u->sock.errorStr().c_str());
+        gLog.error(tr("Chat: Send error (color/font packet): %s"), u->sock.errorStr().c_str());
         return false;
       }
       u->state = CHAT_STATE_WAITxFORxFONT;
@@ -1016,7 +1010,7 @@ bool CChatManager::ProcessPacket(CChatUser *u)
 
     case CHAT_STATE_WAITxFORxFONT:
     {
-      gLog.info(tr("%sChat: Received font packet.\n"), L_TCPxSTR);
+      gLog.info(tr("Chat: Received font packet."));
       CPChat_Font pin(u->sock.RecvBuffer());
 
       // just received the font reply
@@ -1034,7 +1028,7 @@ bool CChatManager::ProcessPacket(CChatUser *u)
 
     case CHAT_STATE_WAITxFORxCOLORxFONT:
     {
-      gLog.info(tr("%sChat: Received color/font packet.\n"), L_TCPxSTR);
+      gLog.info(tr("Chat: Received color/font packet."));
 
       CPChat_ColorFont pin(u->sock.RecvBuffer());
       u->myUserId = pin.userId();
@@ -1062,7 +1056,7 @@ bool CChatManager::ProcessPacket(CChatUser *u)
       // Parse the multiusers list
       if (pin.ChatClients().size() > 0)
       {
-        gLog.info(tr("%sChat: Joined multiparty (%d people).\n"), L_TCPxSTR,
+        gLog.info(tr("Chat: Joined multiparty (%d people)."),
            int(pin.ChatClients().size() + 1));
         ChatClientList::iterator iter;
         for (iter = pin.ChatClients().begin(); iter != pin.ChatClients().end(); ++iter)
@@ -1087,8 +1081,7 @@ bool CChatManager::ProcessPacket(CChatUser *u)
           myFontFamily, m_nFontEncoding, m_nFontStyle);
       if (!u->sock.SendPacket(p_font.getBuffer()))
       {
-        gLog.error("%sChat: Send error (font packet):\n%s%s\n",
-            L_ERRORxSTR, L_BLANKxSTR, u->sock.errorStr().c_str());
+        gLog.error(tr("Chat: Send error (font packet): %s"), u->sock.errorStr().c_str());
         return false;
       }
 
@@ -1100,8 +1093,8 @@ bool CChatManager::ProcessPacket(CChatUser *u)
 
     case CHAT_STATE_CONNECTED:
     default:
-      gLog.error("%sInternal error: ChatManager::ProcessPacket(), invalid state (%d).\n",
-         L_ERRORxSTR, u->state);
+      gLog.error(tr("Internal error: ChatManager::ProcessPacket(), invalid state (%d)."),
+          u->state);
       break;
 
   } // switch
@@ -1145,10 +1138,9 @@ bool CChatManager::ProcessRaw(CChatUser *u)
   if (!u->sock.RecvRaw())
   {
     if (u->sock.Error() == 0)
-      gLog.info(tr("%sChat: Remote end disconnected.\n"), L_TCPxSTR);
+      gLog.info(tr("Chat: Remote end disconnected."));
     else
-      gLog.info(tr("%sChat: Lost remote end:\n%s%s\n"), L_TCPxSTR,
-          L_BLANKxSTR, u->sock.errorStr().c_str());
+      gLog.info(tr("Chat: Lost remote end: %s"), u->sock.errorStr().c_str());
     return false;
   }
 
@@ -1886,8 +1878,7 @@ bool CChatManager::SendBufferToClient(CBuffer *b, unsigned char cmd, CChatUser *
 
   if (!u->sock.SendRaw(&b_out))
   {
-    gLog.warning(tr("%sChat: Send error:\n%s%s\n"), L_WARNxSTR, L_BLANKxSTR,
-        u->sock.errorStr().c_str());
+    gLog.warning(tr("Chat: Send error: %s"), u->sock.errorStr().c_str());
     CloseClient(u);
     return false;
   }
@@ -1916,8 +1907,7 @@ void CChatManager::SendBuffer_Raw(CBuffer *b)
 
       if (!u->sock.SendRaw(b))
       {
-        gLog.warning(tr("%sChat: Send error:\n%s%s\n"), L_WARNxSTR, L_BLANKxSTR,
-            u->sock.errorStr().c_str());
+        gLog.warning(tr("Chat: Send error: %s"), u->sock.errorStr().c_str());
         CloseClient(u);
         ok = false;
         break;
@@ -2328,7 +2318,7 @@ void *ChatManager_tep(void *arg)
           if (chatman->sockman.Num() >= MAX_CONNECTS)
           {
             // Too many sockets, drop this one
-            gLog.warning(tr("%sToo many connected clients, rejecting new connection.\n"), L_WARNxSTR);
+            gLog.warning(tr("Too many connected clients, rejecting new connection."));
           }
           else
           {
@@ -2342,12 +2332,12 @@ void *ChatManager_tep(void *arg)
 
               u->state = CHAT_STATE_HANDSHAKE;
               chatman->chatUsers.push_back(u);
-              gLog.info(tr("%sChat: Received connection.\n"), L_TCPxSTR);
+              gLog.info(tr("Chat: Received connection."));
             }
             else
             {
               delete u;
-              gLog.error(tr("%sChat: Unable to receive new connection.\n"), L_ERRORxSTR);
+              gLog.error(tr("Chat: Unable to receive new connection."));
             }
           }
         }
@@ -2358,7 +2348,7 @@ void *ChatManager_tep(void *arg)
           CChatUser *u = chatman->FindChatUser(nCurrentSocket);
           if (u == NULL)
           {
-            gLog.warning(tr("%sChat: No user owns socket %d.\n"), L_WARNxSTR, nCurrentSocket);
+            gLog.warning(tr("Chat: No user owns socket %d."), nCurrentSocket);
           }
           else
           {
@@ -2404,7 +2394,7 @@ void *ChatWaitForSignal_tep(void *arg)
   pthread_mutex_unlock(cancel_mutex);
 
   pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
-  gLog.info("%sChat: Waiting for reverse connection.\n", L_TCPxSTR);
+  gLog.info(tr("Chat: Waiting for reverse connection."));
   bool bConnected = gIcqProtocol.waitForReverseConnection(rc->nId, rc->u->userId());
   pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
 
@@ -2459,7 +2449,7 @@ void *ChatWaitForSignal_tep(void *arg)
     pthread_mutex_unlock(cancel_mutex);
 
     pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
-    gLog.info("%sChat: Reverse connection failed, trying direct.\n", L_TCPxSTR);
+  gLog.info(tr("Chat: Reverse connection failed, trying direct."));
     bool bSuccess = gIcqProtocol.OpenConnectionToUser("chat", nIp, nIntIp, &rc->u->sock,
                                             nPort, bSendIntIp);
     pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
