@@ -1,14 +1,13 @@
-// -*- c-basic-offset: 2 -*-
 /* ----------------------------------------------------------------------------
  * Licq - A ICQ Client for Unix
- * Copyright (C) 1998-2010 Licq developers
+ * Copyright (C) 1998-2011 Licq developers
  *
  * This program is licensed under the terms found in the LICENSE file.
  */
 
 #include "config.h"
 
-#include <licq/icqfiletransfer.h>
+#include <licq/icq//filetransfer.h>
 
 #include <cstdio>
 #include <ctype.h>
@@ -21,17 +20,14 @@
 #include <string.h>
 #include <sys/time.h>
 
-// Localization
-#include "gettext.h"
-
 #include <licq/logging/log.h>
 #include <licq/contactlist/owner.h>
 #include <licq/contactlist/user.h>
 #include <licq/daemon.h>
 
-#include "icq/icq.h"
-#include "icq/packet.h"
-#include "support.h"
+#include "icq.h"
+#include "packet.h"
+#include "../gettext.h"
 
 #define DEBUG_THREADS(x)
 
@@ -223,7 +219,7 @@ bool CFileTransferManager::StartFileTransferServer()
 {
   if (gDaemon.StartTCPServer(&ftServer) == -1)
   {
-    gLog.warning(tr("%sNo more ports available, add more or close open chat/file sessions.\n"), L_WARNxSTR);
+    gLog.warning(tr("No more ports available, add more or close open chat/file sessions."));
     return false;
   }
 
@@ -246,8 +242,7 @@ bool CFileTransferManager::receiveFiles(const string& directory)
     if (access(Licq::gDaemon.baseDir().c_str(), F_OK) < 0 && mkdir(myDirectory.c_str(), 0700) == -1 &&
         errno != EEXIST)
     {
-      gLog.warning(tr("%sUnable to create directory %s for file transfer.\n"),
-         L_WARNxSTR, myDirectory.c_str());
+      gLog.warning(tr("Unable to create directory %s for file transfer."), myDirectory.c_str());
       myDirectory = Licq::gDaemon.baseDir();
     }
   }
@@ -260,7 +255,7 @@ bool CFileTransferManager::receiveFiles(const string& directory)
   stat(myDirectory.c_str(), &buf);
   if (!S_ISDIR(buf.st_mode))
   {
-    gLog.warning(tr("%sPath %s is not a directory.\n"), L_WARNxSTR, myDirectory.c_str());
+    gLog.warning(tr("Path %s is not a directory."), myDirectory.c_str());
     return false;
   }
 
@@ -298,8 +293,8 @@ void CFileTransferManager::sendFiles(const list<string>& pathNames, unsigned sho
   {
     if (stat(iter->c_str(), &buf) == -1)
     {
-      gLog.warning(tr("%sFile Transfer: File access error %s:\n%s%s.\n"), L_WARNxSTR,
-         iter->c_str(), L_BLANKxSTR, strerror(errno));
+      gLog.warning(tr("File Transfer: File access error %s: %s."),
+         iter->c_str(), strerror(errno));
       continue;
     }
     myPathNames.push_back(*iter);
@@ -338,14 +333,14 @@ bool CFileTransferManager::ConnectToFileServer(unsigned short nPort)
     if (!u.isLocked())
       return false;
 
-    bTryDirect = u->Version() <= 6 || u->Mode() == MODE_DIRECT;
+    bTryDirect = u->Version() <= 6 || u->directMode();
     bSendIntIp = u->SendIntIp();
   }
 
   bool bSuccess = false;
   if (bTryDirect)
   {
-    gLog.info("%sFile Transfer: Connecting to server.\n", L_TCPxSTR);
+    gLog.info(tr("File Transfer: Connecting to server."));
     bSuccess = gIcqProtocol.openConnectionToUser(myUserId, &ftSock, nPort);
    }
 
@@ -382,7 +377,7 @@ bool CFileTransferManager::ConnectToFileServer(unsigned short nPort)
 
 bool CFileTransferManager::SendFileHandshake()
 {
-  gLog.info(tr("%sFile Transfer: Shaking hands.\n"), L_TCPxSTR);
+  gLog.info(tr("File Transfer: Shaking hands."));
 
   // Send handshake packet:
   unsigned short nVersion;
@@ -397,7 +392,7 @@ bool CFileTransferManager::SendFileHandshake()
   CPFile_InitClient p(myLocalName, m_nBatchFiles, m_nBatchSize);
   if (!SendPacket(&p)) return false;
 
-  gLog.info(tr("%sFile Transfer: Waiting for server to respond.\n"), L_TCPxSTR);
+  gLog.info(tr("File Transfer: Waiting for server to respond."));
 
   m_nState = FT_STATE_WAITxFORxSERVERxINIT;
 
@@ -413,8 +408,7 @@ void CFileTransferManager::AcceptReverseConnection(Licq::TCPSocket* s)
 {
   if (ftSock.Descriptor() != -1)
   {
-    gLog.warning(tr("%sFile Transfer: Attempted reverse connection when already connected.\n"),
-       L_WARNxSTR);
+    gLog.warning(tr("File Transfer: Attempted reverse connection when already connected."));
     return;
   }
 
@@ -427,7 +421,7 @@ void CFileTransferManager::AcceptReverseConnection(Licq::TCPSocket* s)
   // Reload socket info
   myThreadPipe.putChar('R');
 
-  gLog.info(tr("%sFile Transfer: Received reverse connection.\n"), L_TCPxSTR);
+  gLog.info(tr("File Transfer: Received reverse connection."));
 }
 
 
@@ -437,10 +431,9 @@ bool CFileTransferManager::ProcessPacket()
   if (!ftSock.RecvPacket())
   {
     if (ftSock.Error() == 0)
-      gLog.info(tr("%sFile Transfer: Remote end disconnected.\n"), L_TCPxSTR);
+      gLog.info(tr("File Transfer: Remote end disconnected."));
     else
-      gLog.warning(tr("%sFile Transfer: Lost remote end:\n%s%s\n"), L_WARNxSTR,
-          L_BLANKxSTR, ftSock.errorStr().c_str());
+      gLog.warning(tr("File Transfer: Lost remote end: %s"), ftSock.errorStr().c_str());
     if (m_nState == FT_STATE_WAITxFORxFILExINFO)
       m_nResult = FT_DONExBATCH;
     else
@@ -461,8 +454,8 @@ bool CFileTransferManager::ProcessPacket()
 
       if (!IcqProtocol::Handshake_Recv(&ftSock, LocalPort(), false))
         break;
-      gLog.info(tr("%sFile Transfer: Received handshake.\n"), L_TCPxSTR);
-      
+      gLog.info(tr("File Transfer: Received handshake."));
+
       unsigned long nId = 0;
       if (ftSock.Version() == 7 || ftSock.Version() == 8)
       {
@@ -499,8 +492,7 @@ bool CFileTransferManager::ProcessPacket()
             return false;
           }
 
-          gLog.info("%sFile Transfer: Waiting for server to respond.\n",
-            L_TCPxSTR);
+          gLog.info(tr("File Transfer: Waiting for server to respond."));
 
           m_nState = FT_STATE_WAITxFORxSERVERxINIT;
           break;
@@ -517,7 +509,7 @@ bool CFileTransferManager::ProcessPacket()
       if (nCmd == 0x05)
       {
         unsigned long nSpeed = b.UnpackUnsignedLong();
-        gLog.info(tr("%sFile Transfer: Speed set to %ld%%.\n"), L_TCPxSTR, nSpeed);
+        gLog.info(tr("File Transfer: Speed set to %ld%%."), nSpeed);
         break;
       }
       if (nCmd != 0x00)
@@ -553,7 +545,7 @@ bool CFileTransferManager::ProcessPacket()
         return false;
       }
 
-      gLog.info(tr("%sFile Transfer: Waiting for file info.\n"), L_TCPxSTR);
+      gLog.info(tr("File Transfer: Waiting for file info."));
       m_nState = FT_STATE_WAITxFORxFILExINFO;
       break;
     }
@@ -564,13 +556,12 @@ bool CFileTransferManager::ProcessPacket()
       if (nCmd == 0x05)
       {
         unsigned long nSpeed = b.UnpackUnsignedLong();
-        gLog.info(tr("%sFile Transfer: Speed set to %ld%%.\n"), L_TCPxSTR, nSpeed);
+        gLog.info(tr("File Transfer: Speed set to %ld%%."), nSpeed);
         break;
       }
       if (nCmd == 0x06 && b.getDataSize() == 1)
       {
-        gLog.info(tr("%sFile Transfer: Ignoring a possible erroneous packet.\n"),
-                  L_WARNxSTR);
+        gLog.info(tr("File Transfer: Ignoring a possible erroneous packet."));
         break;
       }
       if (nCmd != 0x02)
@@ -618,7 +609,7 @@ bool CFileTransferManager::ProcessPacket()
       {
         m_nStartTime = time(NULL);
         m_nBatchPos += m_nFilePos;
-        gLog.info(tr("%sFile Transfer: Receiving %s (%ld bytes).\n"), L_TCPxSTR,
+        gLog.info(tr("File Transfer: Receiving %s (%ld bytes)."),
             myFileName.c_str(), m_nFileSize);
         PushFileTransferEvent(new CFileTransferEvent(FT_STARTxFILE, myPathName));
         gettimeofday(&tv_lastupdate, NULL);
@@ -630,7 +621,7 @@ bool CFileTransferManager::ProcessPacket()
       if (nCmd == 0x05)
       {
         unsigned long nSpeed = b.UnpackUnsignedLong();
-        gLog.info(tr("%sFile Transfer: Speed set to %ld%%.\n"), L_TCPxSTR, nSpeed);
+        gLog.info(tr("File Transfer: Speed set to %ld%%."), nSpeed);
         break;
       }
 
@@ -645,8 +636,8 @@ bool CFileTransferManager::ProcessPacket()
       size_t nBytesWritten = write(m_nFileDesc, b.getDataPosRead(), b.getDataSize() - 1);
       if (nBytesWritten != b.getDataSize() - 1)
       {
-        gLog.error("%sFile Transfer: Write error:\n%s%s.\n", L_ERRORxSTR, L_BLANKxSTR,
-           errno == 0 ? "Disk full (?)" : strerror(errno));
+        gLog.error(tr("File Transfer: Write error: %s."),
+            errno == 0 ? "Disk full (?)" : strerror(errno));
         m_nResult = FT_ERRORxFILE;
         return false;
       }
@@ -676,12 +667,12 @@ bool CFileTransferManager::ProcessPacket()
       m_nFileDesc = -1;
       if (nBytesLeft == 0) // File transfer done perfectly
       {
-        gLog.info(tr("%sFile Transfer: %s received.\n"), L_TCPxSTR, myFileName.c_str());
+        gLog.info(tr("File Transfer: %s received."), myFileName.c_str());
       }
       else // nBytesLeft < 0
       {
         // Received too many bytes for the given size of the current file
-        gLog.warning(tr("%sFile Transfer: %s received %d too many bytes.\n"), L_WARNxSTR,
+        gLog.warning(tr("File Transfer: %s received %d too many bytes."),
             myFileName.c_str(), -nBytesLeft);
       }
       // Notify Plugin
@@ -701,7 +692,7 @@ bool CFileTransferManager::ProcessPacket()
       if (nCmd == 0x05)
       {
         unsigned long nSpeed = b.UnpackUnsignedLong();
-        gLog.info(tr("%sFile Transfer: Speed set to %ld%%.\n"), L_TCPxSTR, nSpeed);
+        gLog.info(tr("File Transfer: Speed set to %ld%%."), nSpeed);
         break;
       }
       if (nCmd != 0x01)
@@ -717,7 +708,7 @@ bool CFileTransferManager::ProcessPacket()
       CPFile_Info p(*myPathNameIter);
       if (!p.IsValid())
       {
-        gLog.warning(tr("%sFile Transfer: Read error for %s:\n%s\n"), L_WARNxSTR,
+        gLog.warning(tr("File Transfer: Read error for %s:\n%s"),
             myPathNameIter->c_str(), p.ErrorStr());
         m_nResult = FT_ERRORxFILE;
         return false;
@@ -747,7 +738,7 @@ bool CFileTransferManager::ProcessPacket()
       if (nCmd == 0x05)
       {
         unsigned long nSpeed = b.UnpackUnsignedLong();
-        gLog.info(tr("%sFile Transfer: Speed set to %ld%%.\n"), L_TCPxSTR, nSpeed);
+        gLog.info(tr("File Transfer: Speed set to %ld%%."), nSpeed);
         break;
       }
       if (nCmd != 0x03)
@@ -765,16 +756,16 @@ bool CFileTransferManager::ProcessPacket()
       m_nFileDesc = open(myPathNameIter->c_str(), O_RDONLY);
       if (m_nFileDesc == -1)
       {
-        gLog.error("%sFile Transfer: Read error '%s':\n%s%s\n.", L_ERRORxSTR,
-            myPathNameIter->c_str(), L_BLANKxSTR, strerror(errno));
+        gLog.error(tr("File Transfer: Read error '%s': %s."),
+            myPathNameIter->c_str(), strerror(errno));
         m_nResult = FT_ERRORxFILE;
         return false;
       }
 
       if (lseek(m_nFileDesc, m_nFilePos, SEEK_SET) == -1)
       {
-        gLog.error("%sFile Transfer: Seek error '%s':\n%s%s\n.", L_ERRORxSTR,
-            myFileName.c_str(), L_BLANKxSTR, strerror(errno));
+        gLog.error(tr("File Transfer: Seek error '%s': %s."),
+            myFileName.c_str(), strerror(errno));
         m_nResult = FT_ERRORxFILE;
         return false;
       }
@@ -789,7 +780,7 @@ bool CFileTransferManager::ProcessPacket()
       if (nCmd == 0x05)
       {
         unsigned long nSpeed = b.UnpackUnsignedLong();
-        gLog.info(tr("%sFile Transfer: Speed set to %ld%%.\n"), L_TCPxSTR, nSpeed);
+        gLog.info(tr("File Transfer: Speed set to %ld%%."), nSpeed);
         break;
       }
       b.log(Log::Unknown, tr("File Transfer: Unknown packet received during file send"));
@@ -799,8 +790,8 @@ bool CFileTransferManager::ProcessPacket()
 
     default:
     {
-      gLog.error("%sInternal error: FileTransferManager::ProcessPacket(), invalid state (%d).\n",
-         L_ERRORxSTR, m_nState);
+      gLog.error(tr("Internal error: FileTransferManager::ProcessPacket(), invalid state (%d)."),
+          m_nState);
       break;
     }
 
@@ -815,12 +806,11 @@ bool CFileTransferManager::ProcessPacket()
 // the actual transfer begins
 bool CFileTransferManager::startReceivingFile(const string& fileName)
 {
-  gLog.info(tr("%sFile Transfer: Received plugin confirmation.\n"), L_TCPxSTR);
-      
+  gLog.info(tr("File Transfer: Received plugin confirmation."));
+
   if (m_nState != FT_STATE_CONFIRMINGxFILE)
   {
-     gLog.warning("%sFile Transfer: StartReceivingFile called without a pending confirmation.\n",
-        L_WARNxSTR);
+     gLog.warning(tr("File Transfer: StartReceivingFile called without a pending confirmation."));
      return false;
   }
 
@@ -852,8 +842,8 @@ bool CFileTransferManager::startReceivingFile(const string& fileName)
     }
     if (m_nFileDesc == -1)
     {
-      gLog.error("%sFile Transfer: Unable to open %s for writing:\n%s%s.\n",
-          L_ERRORxSTR, myPathName.c_str(), L_BLANKxSTR, strerror(errno));
+      gLog.error(tr("File Transfer: Unable to open %s for writing: %s."),
+          myPathName.c_str(), strerror(errno));
       m_nResult = FT_ERRORxFILE;
       return false;
     }
@@ -863,7 +853,7 @@ bool CFileTransferManager::startReceivingFile(const string& fileName)
   CPFile_Start p(m_nFilePos, m_nCurrentFile);
   if (!SendPacket(&p))
   {
-    gLog.error("%sFile Transfer: Unable to send file receive start packet.\n", L_ERRORxSTR);
+    gLog.error(tr("File Transfer: Unable to send file receive start packet."));
     m_nResult = FT_ERRORxCLOSED;
     return false;
   }
@@ -881,7 +871,7 @@ bool CFileTransferManager::SendFilePacket()
   {
     m_nStartTime = time(NULL);
     m_nBatchPos += m_nFilePos;
-    gLog.info(tr("%sFile Transfer: Sending %s (%ld bytes).\n"), L_TCPxSTR,
+    gLog.info(tr("File Transfer: Sending %s (%ld bytes)."),
         myPathName.c_str(), m_nFileSize);
     PushFileTransferEvent(new CFileTransferEvent(FT_STARTxFILE, myPathName));
     gettimeofday(&tv_lastupdate, NULL);
@@ -891,8 +881,8 @@ bool CFileTransferManager::SendFilePacket()
   if (nBytesToSend > 2048) nBytesToSend = 2048;
   if (read(m_nFileDesc, pSendBuf, nBytesToSend) != nBytesToSend)
   {
-    gLog.error("%sFile Transfer: Error reading from %s:\n%s%s.\n", L_ERRORxSTR,
-        myPathName.c_str(), L_BLANKxSTR, strerror(errno));
+    gLog.error(tr("File Transfer: Error reading from %s: %s."),
+        myPathName.c_str(), strerror(errno));
     m_nResult = FT_ERRORxFILE;
     return false;
   }
@@ -936,11 +926,11 @@ bool CFileTransferManager::SendFilePacket()
 
   if (nBytesLeft == 0)
   {
-    gLog.info(tr("%sFile Transfer: Sent %s.\n"), L_TCPxSTR, myFileName.c_str());
+    gLog.info(tr("File Transfer: Sent %s."), myFileName.c_str());
   }
   else // nBytesLeft < 0
   {
-    gLog.info(tr("%sFile Transfer: Sent %s, %d too many bytes.\n"), L_TCPxSTR,
+    gLog.info(tr("File Transfer: Sent %s, %d too many bytes."),
         myFileName.c_str(), -nBytesLeft);
   }
   PushFileTransferEvent(new CFileTransferEvent(FT_DONExFILE, myPathName));
@@ -958,7 +948,7 @@ bool CFileTransferManager::SendFilePacket()
     CPFile_Info p(*myPathNameIter);
     if (!p.IsValid())
     {
-      gLog.warning(tr("%sFile Transfer: Read error for %s:\n%s\n"), L_WARNxSTR,
+      gLog.warning(tr("File Transfer: Read error for %s: %s"),
           myPathNameIter->c_str(), p.ErrorStr());
       m_nResult = FT_ERRORxFILE;
       return false;
@@ -1018,8 +1008,7 @@ bool CFileTransferManager::SendBuffer(CBuffer *b)
 {
   if (!ftSock.SendPacket(b))
   {
-    gLog.warning(tr("%sFile Transfer: Send error:\n%s%s\n"), L_WARNxSTR, L_BLANKxSTR,
-        ftSock.errorStr().c_str());
+    gLog.warning(tr("File Transfer: Send error: %s"), ftSock.errorStr().c_str());
     return false;
   }
   return true;
@@ -1030,7 +1019,7 @@ void CFileTransferManager::ChangeSpeed(unsigned short nSpeed)
 {
   if (nSpeed > 100)
   {
-    gLog.warning(tr("%sInvalid file transfer speed: %d%%.\n"), L_WARNxSTR, nSpeed);
+    gLog.warning(tr("Invalid file transfer speed: %d%%."), nSpeed);
     return;
   }
 
@@ -1130,8 +1119,7 @@ void *FileTransferManager_tep(void *arg)
       //   descriptor and select will continue to fail causing this thread to
       //   spin so better to just give up and exit.
 
-      gLog.warning(tr("%sFile Transfer: select failed, aborting thread:\n%s%s\n"),
-          L_WARNxSTR, L_BLANKxSTR, strerror(errno));
+      gLog.warning(tr("File Transfer: select failed, aborting thread: %s"), strerror(errno));
       pthread_exit(NULL);
     }
 
@@ -1167,7 +1155,7 @@ void *FileTransferManager_tep(void *arg)
         {
           if (ftman->ftSock.Descriptor() != -1)
           {
-            gLog.warning(tr("%sFile Transfer: Receiving repeat incoming connection.\n"), L_WARNxSTR);
+            gLog.warning(tr("File Transfer: Receiving repeat incoming connection."));
 
             // Dump the extra connection to clear the listen socket queue
             Licq::TCPSocket ts;
@@ -1182,11 +1170,11 @@ void *FileTransferManager_tep(void *arg)
               ftman->sockman.DropSocket(&ftman->ftSock);
 
               ftman->m_nState = FT_STATE_HANDSHAKE;
-              gLog.info(tr("%sFile Transfer: Received connection.\n"), L_TCPxSTR);
+              gLog.info(tr("File Transfer: Received connection."));
             }
             else
             {
-              gLog.error(tr("%sFile Transfer: Unable to receive new connection.\n"), L_ERRORxSTR);
+              gLog.error(tr("File Transfer: Unable to receive new connection."));
             }
           }
         }
@@ -1206,7 +1194,7 @@ void *FileTransferManager_tep(void *arg)
 
         else
         {
-          gLog.warning(tr("%sFile Transfer: No such socket.\n"), L_WARNxSTR);
+          gLog.warning(tr("File Transfer: No such socket."));
         }
 
         nSocketsAvailable--;
@@ -1250,7 +1238,7 @@ void *FileWaitForSignal_tep(void *arg)
   pthread_mutex_unlock(cancel_mutex);
 
   pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
-  gLog.info("%sFile Transfer: Waiting for reverse connection.\n", L_TCPxSTR);
+  gLog.info(tr("File Transfer: Waiting for reverse connection.\n"));
   bool bConnected = gIcqProtocol.waitForReverseConnection(rc->nId, userId);
   pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
 
@@ -1274,8 +1262,7 @@ void *FileWaitForSignal_tep(void *arg)
   pthread_mutex_unlock(cancel_mutex);
 
   pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
-  gLog.info("%sFile Transfer: Reverse connection failed, trying direct.\n",
-                                                                    L_TCPxSTR);
+  gLog.info(tr("File Transfer: Reverse connection failed, trying direct."));
   Licq::TCPSocket s;
   bConnected = gIcqProtocol.openConnectionToUser(userId, &s, nPort);
   pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
@@ -1289,8 +1276,7 @@ void *FileWaitForSignal_tep(void *arg)
   {
     if (rc->m->ftSock.Descriptor() != -1)
     {
-      gLog.warning("%sFile Transfer: Attempted connection when already"
-                " connected.\n", L_WARNxSTR);
+      gLog.warning(tr("File Transfer: Attempted connection when already connected."));
     }
     else
     {
