@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010 Licq developers
+ * Copyright (C) 2010-2011 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #ifndef LICQDAEMON_ICQ_H
 #define LICQDAEMON_ICQ_H
 
-#include <licq/icq.h>
+#include <licq/icq/icq.h>
 
 #include <boost/shared_array.hpp>
 #include <list>
@@ -35,6 +35,7 @@
 
 class COscarService;
 class CPacketTcp;
+class CSrvPacketTcp;
 
 namespace Licq
 {
@@ -42,6 +43,7 @@ class INetSocket;
 class IniFile;
 class Packet;
 class TCPSocket;
+class User;
 class UserEvent;
 }
 
@@ -106,6 +108,7 @@ public:
   bool bFinished;
 };
 
+enum EDaemonStatus {STATUS_ONLINE, STATUS_OFFLINE_MANUAL, STATUS_OFFLINE_FORCED };
 
 class IcqProtocol : public CICQDaemon
 {
@@ -120,15 +123,14 @@ public:
   void SetUseServerSideBuddyIcons(bool b);
 
   unsigned long icqSendContactList(const Licq::UserId& userId, const Licq::StringList& users,
-     bool bOnline, unsigned short nLevel, bool bMultipleRecipients = false,
-     const Licq::Color* pColor = NULL);
+      unsigned flags = 0, const Licq::Color* pColor = NULL);
 
   unsigned long icqFetchAutoResponse(const Licq::UserId& userId, bool bServer = false);
   unsigned long icqChatRequest(const Licq::UserId& userId, const std::string& reason,
-     unsigned short nLevel, bool bServer);
+      unsigned flags);
   unsigned long icqMultiPartyChatRequest(const Licq::UserId& userId,
      const std::string& reason, const std::string& chatUsers, unsigned short nPort,
-     unsigned short nLevel, bool bServer);
+      unsigned flags = 0);
   void icqChatRequestRefuse(const Licq::UserId& userId, const std::string& reason,
       unsigned short nSequence, const unsigned long nMsgID[], bool bDirect);
   void icqChatRequestAccept(const Licq::UserId& userId, unsigned short nPort,
@@ -165,8 +167,8 @@ public:
       const Licq::UserCategoryMap& background);
   unsigned long icqSetAbout(const std::string& about);
   unsigned long icqSetPassword(const std::string& password);
-  unsigned long icqSetRandomChatGroup(unsigned long nGroup);
-  unsigned long icqRandomChatSearch(unsigned long nGroup);
+  unsigned long setRandomChatGroup(unsigned chatGroup);
+  unsigned long randomChatSearch(unsigned chatGroup);
   unsigned long icqSearchWhitePages(const std::string& firstName, const std::string& lastName,
       const std::string& alias, const std::string& email, unsigned short minAge, unsigned short maxAge,
       char gender, char language, const std::string& city, const std::string& state,
@@ -179,20 +181,17 @@ public:
   void icqAlertUser(const Licq::UserId& userId);
   void icqUpdatePhoneBookTimestamp();
   void icqUpdatePictureTimestamp();
-  void icqSetPhoneFollowMeStatus(unsigned long nNewStatus);
+  void icqSetPhoneFollowMeStatus(unsigned newStatus);
   void icqUpdateContactList();
   void icqCheckInvisible(const Licq::UserId& userId);
   unsigned long icqSendSms(const Licq::UserId& userId, const std::string& number, const std::string& message);
 
   void icqSendMessage(unsigned long eventId, const Licq::UserId& userId, const std::string& message,
-      bool viaServer, unsigned short nLevel, bool bMultipleRecipients = false,
-      const Licq::Color* pColor = NULL);
+      unsigned flags = 0, const Licq::Color* pColor = NULL);
   void icqSendUrl(unsigned long eventId, const Licq::UserId& userId, const std::string& url,
-      const std::string& message, bool viaServer, unsigned short nLevel,
-      bool bMultipleRecipients = false, const Licq::Color* pColor = NULL);
+      const std::string& message, unsigned flags = 0, const Licq::Color* pColor = NULL);
   void icqFileTransfer(unsigned long eventId, const Licq::UserId& userId, const std::string& filename,
-      const std::string& message, const std::list<std::string>& fileList,
-     unsigned short nLevel, bool bServer);
+      const std::string& message, const std::list<std::string>& fileList, unsigned flags = 0);
   void icqFileTransferRefuse(const Licq::UserId& userId, const std::string& message,
       unsigned short nSequence, const unsigned long nMsgID[], bool viaServer);
   void icqFileTransferCancel(const Licq::UserId& userId, unsigned short nSequence);
@@ -203,11 +202,11 @@ public:
   void icqCloseSecureChannel(unsigned long eventId, const Licq::UserId& userId);
   void icqOpenSecureChannelCancel(const Licq::UserId& userId, unsigned short nSequence);
   void icqFetchAutoResponseServer(unsigned long eventId, const Licq::UserId& userId);
-  unsigned long icqLogon(unsigned short logonStatus);
+  unsigned long logon(unsigned logonStatus);
   unsigned long icqRequestLogonSalt();
   unsigned long icqUserBasicInfo(const Licq::UserId& userId);
   unsigned long icqRequestMetaInfo(const Licq::UserId& userId);
-  unsigned long icqSetStatus(unsigned short newStatus);
+  unsigned long setStatus(unsigned newStatus);
   void icqLogoff();
   void postLogoff(int nSD, Licq::Event* cancelledEvent);
   void icqRelogon();
@@ -216,8 +215,7 @@ public:
   void icqAddGroup(const std::string& groupName);
   void icqRemoveUser(const Licq::UserId& userId, bool ignored = false);
   void icqRemoveGroup(int groupId);
-  void icqChangeGroup(const Licq::UserId& userId, unsigned short _nNewGroup, unsigned short _nOldGSID,
-                      unsigned short _nNewType, unsigned short _nOldType);
+  void icqChangeGroup(const Licq::UserId& userId, unsigned short _nNewGroup, unsigned short _nOldGSID);
   void icqRenameGroup(const std::string& newName, unsigned short _nGSID);
   void icqRenameUser(const Licq::UserId& userId, const std::string& newAlias);
   void icqExportUsers(const std::list<Licq::UserId>& users, unsigned short);
@@ -241,7 +239,7 @@ public:
   void icqRequestSystemMsg();
   Licq::Event* icqSendThroughServer(unsigned long eventId, const Licq::UserId& userId,
       unsigned char format, const std::string& message, Licq::UserEvent*,
-      unsigned short = 0, size_t = 0);
+      unsigned short = 0);
 
   void CheckExport();
   bool openConnectionToUser(const Licq::UserId& userId, Licq::TCPSocket* sock,
@@ -270,7 +268,7 @@ public:
       const unsigned long nMsgID[], unsigned short nSequence,
      bool bIsAck, bool &bNewUser);
 
-  bool ProcessPluginMessage(Licq::Buffer& packet, Licq::User* user, unsigned char nChannel,
+  bool processPluginMessage(Licq::Buffer& packet, Licq::User* user, int channel,
      bool bIsAck, unsigned long nMsgID1,
      unsigned long nMsgID2, unsigned short nSequence,
      Licq::TCPSocket* pSock);
@@ -310,7 +308,7 @@ public:
 
   int ConnectToServer(const char* server, unsigned short port);
   int ConnectToLoginServer();
-  int connectToUser(const Licq::UserId& userId, unsigned char channel);
+  int connectToUser(const Licq::UserId& userId, int channel);
   int reverseConnectToUser(const Licq::UserId& userId, unsigned long nIp,
      unsigned short nPort, unsigned short nVersion, unsigned short nFailedPort,
      unsigned long nId, unsigned long nMsgID1, unsigned long nMsgID2);
@@ -321,6 +319,18 @@ public:
   void PushEvent(Licq::Event*);
   void PushExtendedEvent(Licq::Event*);
 
+  EDaemonStatus Status() const                  { return m_eStatus; }
+
+  void setDirectMode();
+  bool directMode() const { return myDirectMode; }
+
+  static unsigned short icqStatusFromStatus(unsigned status);
+  static unsigned statusFromIcqStatus(unsigned short icqStatus);
+  static unsigned long addStatusFlags(unsigned long nStatus, const Licq::User* u);
+
+  static std::string parseDigits(const std::string& number);
+  static std::string parseRtf(const std::string& rtf);
+
 private:
   static const int PingFrequency = 60;
   static const int UpdateFrequency = 60;
@@ -330,33 +340,52 @@ private:
   bool SendEvent(int nSD, Licq::Packet &, bool);
   bool SendEvent(Licq::INetSocket *, Licq::Packet &, bool);
   void SendEvent_Server(Licq::Packet *packet);
-  Licq::Event* SendExpectEvent_Server(unsigned long eventId, const Licq::UserId& userId, Licq::Packet*, Licq::UserEvent*, bool = false);
-  Licq::Event* SendExpectEvent_Server(const Licq::UserId& userId, Licq::Packet* packet, Licq::UserEvent* ue, bool extendedEvent = false);
+  Licq::Event* SendExpectEvent_Server(unsigned long eventId, const Licq::UserId& userId, CSrvPacketTcp*, Licq::UserEvent*, bool = false);
+  Licq::Event* SendExpectEvent_Server(const Licq::UserId& userId, CSrvPacketTcp* packet, Licq::UserEvent* ue, bool extendedEvent = false);
 
-  Licq::Event* SendExpectEvent_Server(unsigned long eventId, Licq::Packet* packet, Licq::UserEvent* ue, bool extendedEvent = false)
+  Licq::Event* SendExpectEvent_Server(unsigned long eventId, CSrvPacketTcp* packet, Licq::UserEvent* ue, bool extendedEvent = false)
   { return SendExpectEvent_Server(eventId, Licq::UserId(), packet, ue, extendedEvent); }
 
-  Licq::Event* SendExpectEvent_Server(Licq::Packet* packet, Licq::UserEvent* ue, bool extendedEvent = false);
-  Licq::Event* SendExpectEvent_Client(unsigned long eventId, const Licq::User* user, Licq::Packet* packet, Licq::UserEvent* ue);
-  Licq::Event* SendExpectEvent_Client(const Licq::User* user, Licq::Packet* packet, Licq::UserEvent* ue);
+  Licq::Event* SendExpectEvent_Server(CSrvPacketTcp* packet, Licq::UserEvent* ue, bool extendedEvent = false);
+  Licq::Event* SendExpectEvent_Client(unsigned long eventId, const Licq::User* user, CPacketTcp* packet, Licq::UserEvent* ue);
+  Licq::Event* SendExpectEvent_Client(const Licq::User* user, CPacketTcp* packet, Licq::UserEvent* ue);
   Licq::Event* SendExpectEvent(Licq::Event*, void *(*fcn)(void *));
+  unsigned eventCommandFromPacket(Licq::Packet* p);
 
   void AckTCP(CPacketTcp &, int);
   void AckTCP(CPacketTcp &, Licq::TCPSocket*);
 
-  void ChangeUserStatus(Licq::User* u, unsigned long s);
+  void ChangeUserStatus(Licq::User* u, unsigned long s, time_t onlineSince = 0);
   std::string findUserByCellular(const std::string& cellular);
   bool hasServerEvent(unsigned long subSequence) const;
   void StupidChatLinkageFix();
   void addToModifyUsers(unsigned long unique_id, const std::string data);
 
+  unsigned long icqLogon();
+  unsigned long icqSetStatus(unsigned short newStatus);
+
+  /**
+   * Identify a user client based on available data
+   *
+   * @param caps Raw capabilities data
+   * @param numCaps Size of capabilities data
+   * @param userClass User class
+   * @param tcpVersion Protocol version for direct contact
+   * @param ts1 Last info update time
+   * @param ts2 Last ext info update time
+   * @param ts3 Last ext status update time
+   * @param onlineSince Time user went online
+   * @param webPort Web front port
+   * @return Empty string if detection failed, otherwise name and (if possible) version of user client
+   */
+  std::string detectUserClient(const char* caps, int capSize, int userClass,
+      int tcpVersion, unsigned ts1, unsigned ts2, unsigned ts3,
+      time_t onlineSince, int webPort);
 
   Licq::Pipe myNewSocketPipe;
   unsigned long m_nDesiredStatus;
   unsigned short m_nServerSequence;
   unsigned myMaxUsersPerPacket;
-  unsigned myErrorTypes;
-  std::string myErrorFile;
   int m_nTCPSrvSocketDesc,
       m_nTCPSocketDesc;
   bool m_bLoggingOn,
@@ -370,6 +399,8 @@ private:
   time_t m_tLogonTime;
   std::string myRegisterPasswd;
   pthread_t m_nRegisterThreadId;
+  bool myDirectMode;
+  EDaemonStatus m_eStatus;
 
   // Services
   COscarService *m_xBARTService;
@@ -389,8 +420,7 @@ private:
   std::map <unsigned long, std::string> m_lszModifyServerUsers;
   pthread_mutex_t mutex_modifyserverusers;
   pthread_mutex_t mutex_cancelthread;
-  pthread_t thread_monitorsockets,
-            thread_ping,
+  pthread_t thread_ping,
             thread_updateusers,
             thread_ssbiservice;
 
@@ -400,7 +430,7 @@ private:
 
   friend void *Ping_tep(void *p);
   friend void *UpdateUsers_tep(void *p);
-  friend void *MonitorSockets_tep(void *p);
+  friend void *MonitorSockets_func();
   friend void *ProcessRunningEvent_Client_tep(void *p);
   friend void *ProcessRunningEvent_Server_tep(void *p);
   friend void *Shutdown_tep(void *p);
